==> android-sdk-1.4.0-sources.jar: com/optimizely/ab/android/sdk/OptimizelyStartListener.java <==
/****************************************************************************
 * Copyright 2016, Optimizely, Inc. and contributors                        *
 *                                                                          *
 * Licensed under the Apache License, Version 2.0 (the "License");          *
 * you may not use this file except in compliance with the License.         *
 * You may obtain a copy of the License at                                  *
 *                                                                          *
 *    http://www.apache.org/licenses/LICENSE-2.0                            *
 *                                                                          *
 * Unless required by applicable law or agreed to in writing, software      *
 * distributed under the License is distributed on an "AS IS" BASIS,        *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 * See the License for the specific language governing permissions and      *
 * limitations under the License.                                           *
 ***************************************************************************/

package com.optimizely.ab.android.sdk;

import android.app.Activity;
import android.content.Context;

/**
 * Listens for new instances of {@link OptimizelyClient} that are built after calling
 * {@link OptimizelyManager#initialize(Activity, OptimizelyStartListener)} or {@link OptimizelyManager#initialize(Context, OptimizelyStartListener)}
 */
public interface OptimizelyStartListener {
    /**
     * Receives a started {@link OptimizelyClient} instances
     *
     * @param optimizely an {@link OptimizelyClient} that is started
     */
    void onStart(OptimizelyClient optimizely);
}

==> android-sdk-3.0.0-sources.jar: com/optimizely/ab/android/sdk/OptimizelyStartListener.java <==
/****************************************************************************
 * Copyright 2016, Optimizely, Inc. and contributors                        *
 *                                                                          *
 * Licensed under the Apache License, Version 2.0 (the "License");          *
 * you may not use this file except in compliance with the License.         *
 * You may obtain a copy of the License at                                  *
 *                                                                          *
 *    http://www.apache.org/licenses/LICENSE-2.0                            *
 *                                                                          *
 * Unless required by applicable law or agreed to in writing, software      *
 * distributed under the License is distributed on an "AS IS" BASIS,        *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 * See the License for the specific language governing permissions and      *
 * limitations under the License.                                           *
 ***************************************************************************/

package com.optimizely.ab.android.sdk;

import android.app.Activity;
import android.content.Context;

/**
 * Listens for new instances of {@link OptimizelyClient} that are built after calling
 *{@link OptimizelyManager#initialize(Context, Integer,OptimizelyStartListener)}
 */
public interface OptimizelyStartListener {
    /**
     * Receives a started {@link OptimizelyClient} instances
     *
     * @param optimizely an {@link OptimizelyClient} that is started
     */
    void onStart(OptimizelyClient optimizely);
}
